==> haskell-rio-prettyprint-0.1.8.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-prettyprint
version:              0.1.8.0
visibility:           public
id:                   rio-prettyprint-0.1.8.0-ARbiFfEhHLh5qPGJHlLObE
key:                  rio-prettyprint-0.1.8.0-ARbiFfEhHLh5qPGJHlLObE
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  2abf5857069fa2d1d86f838d6058670b
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.8.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.8.0-ARbiFfEhHLh5qPGJHlLObE
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-4XssoWP8s0tKPHSv4bO4jS
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-tIaEKtcHqOD2jCqJ7RqTi array-0.5.4.0
    base-4.17.2.1 colour-2.3.6-G72z7SH6O4C2fokoLCMx4K mtl-2.2.2
    path-0.9.5-3ZenJsgFHOJG6CCFPhuAX0
    rio-0.1.22.0-BwQmB4ApvGz8BlK4bffc9S text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.8.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-prettyprint
version:              0.1.8.0
visibility:           public
id:                   rio-prettyprint-0.1.8.0-CxKQRlJsntE1kBBb2qrnuq
key:                  rio-prettyprint-0.1.8.0-CxKQRlJsntE1kBBb2qrnuq
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  6a5fa6b4a7a2b24d4c7b817ae7d3c66f
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.8.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.8.0-CxKQRlJsntE1kBBb2qrnuq
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-IimOqSN1qRUFeipP6ofJQ array-0.5.4.0
    base-4.17.2.1 colour-2.3.6-G7rddIa5msdEQoPn9XzuiE mtl-2.2.2
    path-0.9.5-GmZ9zGT3RVnHvefHnR7R06
    rio-0.1.22.0-9BzZI8E4KHO1ZDjPG7ERXG text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
